ThreadCommit

Struct ThreadCommit 

pub struct ThreadCommit {
    pub fencing_token: Option<u64>,
    pub checkpoint: Checkpoint,
    pub history: HistoryMutation,
    pub acknowledge_event: Option<EventId>,
    pub event: Option<DurableEvent>,
    pub recovery_context: Option<InvocationContext>,
}
One atomic state transition requested by Runtime.

Fields

fencing_token: Option<u64>

Lease fencing token required by distributed implementations.

checkpoint: Checkpoint

Replacement Runtime checkpoint.

history: HistoryMutation

Atomic prompt-history append or replacement.

acknowledge_event: Option<EventId>

Exact pending event durably acknowledged by the downstream consumer.

event: Option<DurableEvent>

Event that becomes durable with the checkpoint revision.

recovery_context: Option<InvocationContext>

Context indexed by distributed deployments while this checkpoint or its outbox needs recovery. None removes the thread from the runnable recovery index.