pub struct LlmModelSnapshot {
pub capabilities: ModelCapabilities,
pub generation_support: LlmGenerationSupport,
}Expand description
Model facts captured by the deployment with the desired route parameters. This snapshot belongs to admission, not to the provider-neutral LLM request.
Fields
capabilities: ModelCapabilitiesgeneration_support: LlmGenerationSupportTrait Implementations
Sourceimpl Clone for LlmModelSnapshot
impl Clone for LlmModelSnapshot
Sourcefn clone(&self) -> LlmModelSnapshot
fn clone(&self) -> LlmModelSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LlmModelSnapshot
impl Debug for LlmModelSnapshot
Sourceimpl<'de> Deserialize<'de> for LlmModelSnapshot
impl<'de> Deserialize<'de> for LlmModelSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for LlmModelSnapshot
impl PartialEq for LlmModelSnapshot
Sourceimpl Serialize for LlmModelSnapshot
impl Serialize for LlmModelSnapshot
impl StructuralPartialEq for LlmModelSnapshot