Consumer-owned contracts for the Agent runtime.
This crate contains transport-neutral domain types and ports. Implementations live in the local
MeowCore composition or the private agent-cloud composition.
Re-exports
pub use crate::ConversationSurface;pub use agent::AccessMode;pub use agent::AgentCommand;pub use agent::Interaction;pub use agent::InteractionDecision;pub use agent::QueuedRun;pub use agent::RunOptions;pub use context::Actor;pub use context::InvocationContext;pub use context::Scope;pub use error::ExternalError;pub use error::ExternalErrorKind;pub use event::AgentEvent;pub use event::AgentObservation;pub use event::DurableEvent;pub use event::EventPublisher;pub use event::Observer;pub use facade::AppFacade;pub use facade::ClientTask;pub use facade::FacadeRequest;pub use facade::FacadeResult;pub use facade::InteractionKind;pub use facade::InteractionPreview;pub use facade::InteractionTone;pub use facade::PreparedAction;pub use facade::PreviewDetail;pub use facade::PreviewValue;pub use id::ActionId;pub use id::ClientId;pub use id::EventId;pub use id::MessageId;pub use id::OperationId;pub use id::RunId;pub use id::ScopeId;pub use id::TenantId;pub use id::ThreadId;pub use id::UserId;pub use llm::ApprovalPolicy;pub use llm::ApprovalRequirement;pub use llm::Llm;pub use llm::LlmFailure;pub use llm::ToolDefinition;pub use llm::ToolEffect;pub use llm::ToolPolicy;pub use llm::UsageSummary;pub use operational_context::ContextGeneration;pub use operational_context::ContextInvalidation;pub use operational_context::ContextSource;pub use operational_context::OperationalContext;pub use operational_context::OperationalContextDelta;pub use storage::Checkpoint;pub use storage::ClaimNextOutcome;pub use storage::CommitOutcome;pub use storage::HistoryMutation;pub use storage::QueueSnapshot;pub use storage::QueueStore;pub use storage::Revision;pub use storage::RunControl;pub use storage::RunCoordinator;pub use storage::RunLease;pub use storage::RuntimeSnapshot;pub use storage::StoreError;pub use storage::ThreadCommit;pub use storage::ThreadKey;pub use storage::ThreadRecord;pub use storage::ThreadStore;
Modules
- agent
- Commands accepted by the transport-independent Runtime.
- context
- Invocation identity and tracing context.
- error
- Stable error semantics exposed by external ports.
- event
- Durable Agent events and their delivery boundary.
- facade
- App Facade contract used by the canonical Agent implementation.
- id
- Strongly typed identifiers shared by contracts.
- llm
- Agent model port and execution policy, using the shared model contract.
- operational_
context - Structured operational-context boundary.
- storage
- Persistence contracts expressed in Agent consistency semantics.
- wire
- Versioned transport contract for Agent commands, events, and App Facade calls.
Structs
- Artifact
Metadata - Immutable metadata encoded into an artifact URI.
- Artifact
Reference - Canonical, scope-owned, content-addressed artifact identity.
- Completion
- Provider-neutral completion returned to Runtime.
- Completion
Request - One logical LLM invocation.
- Continuation
- Provider-issued replay data attached to exactly one completed model message. Adapters own the format and compatibility key. Callers must not synthesize or edit payloads.
- Message
- Provider-neutral conversation message.
- Model
Constraints - Capabilities required by an invocation, without naming a provider or model.
- Model
Mode - Logical model mode selected by the product, independent of provider and model identifiers.
- Model
Profile - Provider-neutral limits for one frozen logical model route.
- Token
Usage - Normalized token accounting reported by an implementation.
- Tool
Call - Tool call returned by an LLM.
- UseCase
- Logical model use case resolved by the deployment’s LLM implementation.
Enums
- Artifact
Kind - Logical media kind encoded in an artifact reference.
- Content
Part - One typed part of a model message.
- Finish
Reason - Why a model invocation stopped.
- Message
Role - Role of a message in a model conversation.
Constants
- ARTIFACT_
URL_ PREFIX - Prefix of the version 1 artifact URI format.